@@ -305,9 +305,11 @@ impl<P: Sync + Send + Serialize + DeserializeOwned> Checkout<P> {
             let item = Item {
                 sku: sku.to_string(),
                 title: product.title.clone(),
+                description: product.description.clone(),
                 quantity,
                 price: product.price.clone(),
                 discount: Money::new(self.currency.clone(), "0"),
+                images: product.images.clone(),
             };
             self.items.push(item);
         }
