@@ -44,9 +44,11 @@ pub struct Service {
 pub trait ShippingCalculator {
     async fn get_shipping_quotes(
         &mut self,
-        currency: &Currency,
-        promo_codes: &Vec<String>,
-        items: &Vec<Item>,
-        address: &Address,
-    ) -> Result<Vec<ShippingQuote>, Error>;
+        _currency: &Currency,
+        _promo_codes: &Vec<String>,
+        _items: &Vec<Item>,
+        _address: &Address,
+    ) -> Result<Vec<ShippingQuote>, Error> {
+        Ok(vec![])
+    }
 }
